@@ -14,8 +14,8 @@ sub ACTION_build {
     $self->depends_on('code');
     $self->depends_on('docs');
     $self->depends_on('distmeta'); # regenerate META.yml
-    $self->depends_on('man');
-    $self->depends_on('postats');
+    $self->depends_on('man') unless ($^O eq 'MSWin32');
+    $self->depends_on('postats') unless ($^O eq 'MSWin32');
 }
 
 sub make_files_writable {
@@ -76,10 +76,10 @@ sub ACTION_binpo {
         print "XX po/bin/po4a.pot uptodate.\n";
     }
 
-    # DO NOT update languages. They are updated by the weblate robot directly
-  if (0) {
     foreach (@{$self->rscan_dir('po/bin',qr{\.po$})}) {
         my $lang = fileparse($_, qw{.po});
+      # DO NOT update languages. They are updated by the weblate robot directly
+      if (0) {
         unless ($self->up_to_date("po/bin/po4a.pot", $_)) {
             print "XX Sync $_: ";
             system("msgmerge --previous $_ po/bin/po4a.pot -o $_.new") && die;
@@ -98,12 +98,12 @@ sub ACTION_binpo {
         } else {
             print "XX $_ uptodate.\n";
         }
+      }
         unless ($self->up_to_date($_,"blib/po/$lang/LC_MESSAGES/po4a.mo")) {
             mkpath( File::Spec->catdir( 'blib', 'po', $lang, "LC_MESSAGES" ), 0, oct(755) );
             system("msgfmt -o blib/po/$lang/LC_MESSAGES/po4a.mo $_") && die;
         }
     }
-  }
 }
 
 sub ACTION_install {
@@ -151,7 +151,7 @@ sub ACTION_docpo {
     $self->depends_on('code');
     $self->make_files_writable("po/pod");
 
-    my $cmd = "PERL5LIB=lib perl po4a "; # Use this version of po4a
+    my $cmd = "perl -Ilib po4a "; # Use this version of po4a
     $cmd .= "--previous ";
     $cmd .= "--no-translations ";
     $cmd .= "--msgid-bugs-address devel\@lists.po4a.org ";
@@ -178,7 +178,7 @@ sub ACTION_man {
     my $manpath  = File::Spec->catdir( 'blib', 'man' );
     File::Path::rmtree( $manpath, 0, 1);
 
-    my $cmd = "PERL5LIB=lib perl po4a "; # Use this version of po4a
+    my $cmd = "perl -Ilib po4a "; # Use this version of po4a
     $cmd .= $ENV{PO4AFLAGS}." " if defined($ENV{PO4AFLAGS});
     $cmd .= "--previous po/pod.cfg";
     system($cmd) and die;
@@ -234,27 +234,29 @@ sub ACTION_man {
         }
         $parser->parse_from_file ($file, $out);
 
-        system("gzip -9 -f $out") and die;
+        system("gzip -9 -n -f $out") and die;
         unlink "$file" || die;
     }
 
-    # Install the manpages written in XML DocBook
-    foreach $file (qw(po4a-display-man.xml po4a-display-pod.xml)) {
-        copy ( File::Spec->catdir("share", "doc", $file), $man1path) or die;
-    }
-    foreach $file (@{$self->rscan_dir($manpath, qr{\.xml$})}) {
-        if ($file =~ m,(.*/man(.))/([^/]*)\.xml$,) {
-            my ($outdir, $section, $outfile) = ($1, $2, $3);
-	    if (-e "/usr/share/xml/docbook/stylesheet/docbook-xsl/manpages/docbook.xsl") { # Location on Debian at least
-		print "Convert $outdir/$outfile.$section (local docbook.xsl file). ";
-		system("xsltproc -o $outdir/$outfile.$section --nonet /usr/share/xml/docbook/stylesheet/docbook-xsl/manpages/docbook.xsl $file") and die;
-	    } else { # Not found locally, use the XSL file online
-		print "Convert $outdir/$outfile.$section (online docbook.xsl file). ";
-		system("xsltproc -o $outdir/$outfile.$section --nonet http://docbook.sourceforge.net/release/xsl/current/manpages/docbook.xsl $file") and die;
-	    }
-            system ("gzip -9 -f $outdir/$outfile.$section") and die;
+    if ($^O ne 'MSWin32') {
+        # Install the manpages written in XML DocBook
+        foreach $file (qw(po4a-display-man.xml po4a-display-pod.xml)) {
+            copy ( File::Spec->catdir("share", "doc", $file), $man1path) or die;
+        }
+        foreach $file (@{$self->rscan_dir($manpath, qr{\.xml$})}) {
+            if ($file =~ m,(.*/man(.))/([^/]*)\.xml$,) {
+                my ($outdir, $section, $outfile) = ($1, $2, $3);
+            if (-e "/usr/share/xml/docbook/stylesheet/docbook-xsl/manpages/docbook.xsl") { # Location on Debian at least
+            print "Convert $outdir/$outfile.$section (local docbook.xsl file). ";
+            system("xsltproc -o $outdir/$outfile.$section --nonet /usr/share/xml/docbook/stylesheet/docbook-xsl/manpages/docbook.xsl $file") and die;
+            } else { # Not found locally, use the XSL file online
+            print "Convert $outdir/$outfile.$section (online docbook.xsl file). ";
+            system("xsltproc -o $outdir/$outfile.$section --nonet http://docbook.sourceforge.net/release/xsl/current/manpages/docbook.xsl $file") and die;
+            }
+                system ("gzip -9 -n -f $outdir/$outfile.$section") and die;
+            }
+            unlink "$file" || die;
         }
-        unlink "$file" || die;
     }
 }
 
