@@ -20,55 +20,59 @@ use warnings;
 require Exporter;
 
 use vars qw(@ISA @EXPORT $AUTOLOAD);
-@ISA = qw(Locale::Po4a::TransTractor);
+@ISA    = qw(Locale::Po4a::TransTractor);
 @EXPORT = qw();
 
-my $debug=0;
-
-sub initialize {}
+my $debug = 0;
 
+sub initialize { }
 
 sub parse {
-    my $self=shift;
-    my ($line,$ref);
+    my $self = shift;
+    my ( $line, $ref );
     my $par;
 
-    LINE:
-    ($line,$ref)=$self->shiftline();
+  LINE:
+    ( $line, $ref ) = $self->shiftline();
 
-    while (defined($line)) {
+    while ( defined($line) ) {
         chomp($line);
-        print STDERR  "begin\n" if $debug;
+        print STDERR "begin\n" if $debug;
+
+        if ( $line =~ /\"/ ) {
+            print STDERR "Start of line containing \".\n" if $debug;
 
-        if ($line =~ /\"/) {
-            print STDERR  "Start of line containing \".\n" if $debug;
             # Text before the first quote
             $line =~ m/(^[^"\r\n]*)"/;
             my $pre_text = $1;
-            print STDERR  "  PreText=".$pre_text."\n" if $debug;
+            print STDERR "  PreText=" . $pre_text . "\n" if $debug;
+
             # The text for translation
             $line =~ m/"([^\r\n]*)"/;
             my $quoted_text = $1;
-            print STDERR  "  QuotedText=".$quoted_text."\n" if $debug;
+            print STDERR "  QuotedText=" . $quoted_text . "\n" if $debug;
+
             # Text after last quote
             $line =~ m/"([^"\n]*$)/;
             my $post_text = $1;
-            print STDERR  "  PostText=".$post_text."\n" if $debug;
+            print STDERR "  PostText=" . $post_text . "\n" if $debug;
+
             # Translate the string it
-            $par = $self->translate($quoted_text, $ref, $pre_text);
+            $par = $self->translate( $quoted_text, $ref, $pre_text );
+
             # Escape the \n characters
             $par =~ s/\n/\\n/g;
+
             # Now push the result
-            $self->pushline($pre_text.'"'.$par.'"'.$post_text."\n");
-            print STDERR  "End of line containing \".\n" if $debug;
-        }
-        else
-        {
+            $self->pushline( $pre_text . '"' . $par . '"' . $post_text . "\n" );
+            print STDERR "End of line containing \".\n" if $debug;
+        } else {
             print STDERR "Other stuff\n" if $debug;
             $self->pushline("$line\n");
         }
+
         # Reinit the loop
-        ($line,$ref)=$self->shiftline();
+        ( $line, $ref ) = $self->shiftline();
     }
 }
 
