@@ -399,7 +399,7 @@ sub parse_file {
         my ( $tmpfh, $tmpfile ) = File::Temp::tempfile(
             "po4a-XXXX",
             SUFFIX => ".sgml",
-            DIR    => $ENV{TMPDIR} || "/tmp",
+            DIR    => File::Spec->tmpdir(),
             UNLINK => 0
         );
         print $tmpfh $origfile;
@@ -434,7 +434,7 @@ sub parse_file {
     # Get the prolog
     {
         $prolog = $origfile;
-        my $lvl;    # number of '<' seen without matching '>'
+        my $lvl;        # number of '<' seen without matching '>'
         my $pos = 0;    # where in the document (in chars) while detecting prolog boundaries
 
         unless ( $prolog =~ s/^(.*<!DOCTYPE).*$/$1/is ) {
@@ -773,7 +773,7 @@ sub parse_file {
             while ( $origfile =~ /^(.*?)&$key(;.*$|[^-_:.A-Za-z0-9].*$|$)/s ) {
 
                 # Since we will include a new file, we
-                # must do a new round of substitutions.
+                #must do a new round of substitutions.
                 $dosubstitution = 1;
                 my ( $begin, $end ) = ( $1, $2 );
                 $end = "" unless ( defined $end );
@@ -789,7 +789,7 @@ sub parse_file {
                 # add the refs
                 my $len  = $entincl{$key}{'length'};    # number added by the inclusion
                 my $pre  = ( $begin =~ tr/\n/\n/ );     # number of \n
-                my $post = ( $end =~ tr/\n/\n/ );
+                my $post = ( $end   =~ tr/\n/\n/ );
                 print "XX Add a ref. pre=$pre; len=$len; post=$post\n"
                   if $debug{'refs'};
 
@@ -852,7 +852,7 @@ sub parse_file {
     my ( $tmpfh, $tmpfile ) = File::Temp::tempfile(
         "po4a-XXXX",
         SUFFIX => ".sgml",
-        DIR    => $ENV{TMPDIR} || "/tmp",
+        DIR    => File::Spec->tmpdir(),
         UNLINK => 0
     );
     print $tmpfh $origfile;
