@@ -11,7 +11,7 @@ use warnings;
 
 use subs qw(makespace);
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = "0.67";
+$VERSION = "0.69";
 @ISA     = qw(DynaLoader);
 @EXPORT  = qw(new process translate
   read write readpo writepo
@@ -262,10 +262,6 @@ Sets the verbosity.
 
 Sets the debugging.
 
-=item B<dedup>
-
-Boolean indicating whether we should deduplicate msgids. Passed to Po.pm as is. See Po.pm documentation for more info.
-
 =back
 
 =cut
@@ -377,7 +373,6 @@ sub new {
     $self->{options}{'package-name'}       = '';
     $self->{options}{'package-version'}    = '';
     $self->{options}{'wrap-po'}            = '';
-    $self->{options}{'dedup'}              = 0;    # Deduplicate msgids, to help gettextization
 
     # let the plugin parse the options and such
     $self->initialize(%options);
@@ -390,7 +385,6 @@ sub new {
     $po_options{'package-name'}       = $options{'package-name'};
     $po_options{'package-version'}    = $options{'package-version'};
     $po_options{'wrap-po'}            = $options{'wrap-po'};
-    $po_options{'dedup'}              = $options{'dedup'};
 
     # private data
     $self->{TT}         = ();
@@ -1183,11 +1177,12 @@ sub encode_from_to {
     return $text;
 }
 
-# Push the translation of a Yaml Front-Matter header that was parsed by YAML::Tiny
+# Push the translation of a Yaml document or Yaml Front-Matter header, parsed by YAML::Tiny in any case
+# $is_yfm is a boolean indicating whether we are dealing with a Front Matter (true value) or whole document (false value)
 sub handle_yaml {
-    my ( $self, $blockref, $yamlarray, $yfm_keys, $yfm_skip_array ) = @_;
+    my ( $self, $is_yfm, $blockref, $yamlarray, $yfm_keys, $yfm_skip_array, $yfm_paths ) = @_;
 
-    die "Empty YAML Front Matter" unless ( length($yamlarray) > 0 );
+    die "Empty YAML " . ($is_yfm?"Front Matter":"document") unless ( length($yamlarray) > 0 );
 
     my ( $indent, $ctx ) = ( 0, "" );
     foreach my $cursor (@$yamlarray) {
@@ -1202,13 +1197,13 @@ sub handle_yaml {
         } elsif ( !ref $cursor ) {
             $self->pushline("---\n");
             $self->pushline(
-                format_scalar( $self->translate( $cursor, $blockref, "YAML Front Matter (scalar)", "wrap" => 0 ) ) );
+                format_scalar( $self->translate( $cursor, $blockref, "YAML ".($is_yfm?"Front Matter ":"")."(scalar)", "wrap" => 0 ) ) );
 
             # A list at the root
         } elsif ( ref $cursor eq 'ARRAY' ) {
             if (@$cursor) {
                 $self->pushline("---\n");
-                do_array( $self, $blockref, $cursor, $indent, $ctx, $yfm_keys, $yfm_skip_array );
+                do_array( $self, $is_yfm, $blockref, $cursor, $indent, $ctx, $yfm_keys, $yfm_skip_array, $yfm_paths );
             } else {
                 $self->pushline("---[]\n");
             }
@@ -1217,7 +1212,7 @@ sub handle_yaml {
         } elsif ( ref $cursor eq 'HASH' ) {
             if (%$cursor) {
                 $self->pushline("---\n");
-                do_hash( $self, $blockref, $cursor, $indent, $ctx, $yfm_keys, $yfm_skip_array );
+                do_hash( $self, $is_yfm, $blockref, $cursor, $indent, $ctx, $yfm_keys, $yfm_skip_array, $yfm_paths );
             } else {
                 $self->pushline("--- {}\n");
             }
@@ -1225,7 +1220,6 @@ sub handle_yaml {
         } else {
             die( "Cannot serialize " . ref($cursor) );
         }
-        $self->pushline("---\n");
     }
 
     # Escape the string to make it valid in YAML.
@@ -1259,7 +1253,7 @@ sub handle_yaml {
     }
 
     sub do_array {
-        my ( $self, $blockref, $array, $indent, $ctx, $yfm_keys, $yfm_skip_array ) = @_;
+        my ( $self, $is_yfm, $blockref, $array, $indent, $ctx, $yfm_keys, $yfm_skip_array, $yfm_paths ) = @_;
         foreach my $el (@$array) {
             my $header = ( '  ' x $indent ) . '- ';
             my $type   = ref $el;
@@ -1268,14 +1262,14 @@ sub handle_yaml {
                     $self->pushline( $header . YAML::Tiny::_dump_scalar( "dummy", $el, 0 ) . "\n" );
                 } else {
                     $self->pushline( $header
-                          . format_scalar( $self->translate( $el, $blockref, "YAML Front Matter:$ctx", "wrap" => 0 ) )
+                          . format_scalar( $self->translate( $el, $blockref, ($is_yfm?"Yaml Front Matter ":"")."Array Element:$ctx", "wrap" => 0 ) )
                           . "\n" );
                 }
 
             } elsif ( $type eq 'ARRAY' ) {
                 if (@$el) {
                     $self->pushline( $header . "\n" );
-                    do_array( $self, $blockref, $el, $indent + 1, $ctx, $yfm_keys, $yfm_skip_array );
+                    do_array( $self, $is_yfm, $blockref, $el, $indent + 1, $ctx, $yfm_keys, $yfm_skip_array, $yfm_paths );
                 } else {
                     $self->pushline( $header . " []\n" );
                 }
@@ -1283,7 +1277,7 @@ sub handle_yaml {
             } elsif ( $type eq 'HASH' ) {
                 if ( keys %$el ) {
                     $self->pushline( $header . "\n" );
-                    do_hash( $self, $blockref, $el, $indent + 1, $ctx, $yfm_keys, $yfm_skip_array );
+                    do_hash( $self, $is_yfm, $blockref, $el, $indent + 1, $ctx, $yfm_keys, $yfm_skip_array, $yfm_paths );
                 } else {
                     $self->pushline( $header . " {}\n" );
                 }
@@ -1295,19 +1289,27 @@ sub handle_yaml {
     }
 
     sub do_hash {
-        my ( $self, $blockref, $hash, $indent, $ctx, $yfm_keys, $yfm_skip_array ) = @_;
+        my ( $self, $is_yfm, $blockref, $hash, $indent, $ctx, $yfm_keys, $yfm_skip_array, $yfm_paths ) = @_;
 
         foreach my $name ( sort keys %$hash ) {
             my $el     = $hash->{$name};
             my $header = ( '  ' x $indent ) . YAML::Tiny::_dump_scalar( "dummy", $name, 1 ) . ":";
             my $type   = ref $el;
             if ( !$type ) {
-                my %keys = %{$yfm_keys};
-                if ( ( not %keys ) || $keys{$name} ) {  # either no key is provided, or the key we need is also provided
-                    my $translation = $self->translate( $el, $blockref, "YAML Front Matter:$ctx $name", "wrap" => 0 );
-                    if ( $el =~ /^\[.*\]$/  ) { # Do not quote the lists
+                my %keys =  %{$yfm_keys};
+                my %paths = %{$yfm_paths};
+                my $path = "$ctx $name" =~ s/^\s+|\s+$//gr; # Need to trim the path, at least when there is no ctx yet
+
+                if ( ($el eq 'false') or ($el eq 'true') ) {   # Do not translate not quote booleans
+                    $self->pushline("$header $el\n");
+                } elsif ( ( scalar %keys  > 0 && exists $keys{$name}) or  # the key we need is provided
+                          ( scalar %paths > 0 && exists $paths{$path}) or # that path is provided
+                          ( scalar %keys == 0 && scalar %paths == 0) ) {  # no key and no path provided
+                    my $translation = $self->translate( $el, $blockref, ($is_yfm?"Yaml Front Matter ":"")."Hash Value:$ctx $name", "wrap" => 0 );
+                    if ( $el =~ /^\[.*\]$/ ) {          # Do not quote the lists
                         $self->pushline( $header . " $translation\n" );
                     } else {
+
                         # add extra quotes to the parameter, as a protection to the extra chars that the translator could add
                         $self->pushline( $header . ' ' . format_scalar($translation) . "\n" );
                     }
@@ -1317,7 +1319,7 @@ sub handle_yaml {
                     # See https://github.com/Perl-Toolchain-Gang/YAML-Tiny#additional-perl-specific-notes
                     if ( Scalar::Util::looks_like_number($el) ) {
                         $self->pushline("$header $el\n");
-                    } elsif ( $el =~ /^\[.*\]$/ ) { # Do not quote the lists either
+                    } elsif ( $el =~ /^\[.*\]$/ ) {    # Do not quote the lists either
                         $self->pushline("$header $el\n");
                     } else {
                         $self->pushline( $header . ' ' . YAML::Tiny::_dump_scalar( "dummy", $el ) . "\n" );
@@ -1327,7 +1329,7 @@ sub handle_yaml {
             } elsif ( $type eq 'ARRAY' ) {
                 if (@$el) {
                     $self->pushline( $header . "\n" );
-                    do_array( $self, $blockref, $el, $indent + 1, "$ctx $name", $yfm_keys, $yfm_skip_array );
+                    do_array( $self, $is_yfm, $blockref, $el, $indent + 1, "$ctx $name", $yfm_keys, $yfm_skip_array, $yfm_paths );
                 } else {
                     $self->pushline( $header . " []\n" );
                 }
@@ -1335,7 +1337,7 @@ sub handle_yaml {
             } elsif ( $type eq 'HASH' ) {
                 if ( keys %$el ) {
                     $self->pushline( $header . "\n" );
-                    do_hash( $self, $blockref, $el, $indent + 1, "$ctx $name", $yfm_keys, $yfm_skip_array );
+                    do_hash( $self, $is_yfm, $blockref, $el, $indent + 1, "$ctx $name", $yfm_keys, $yfm_skip_array, $yfm_paths );
                 } else {
                     $self->pushline( $header . " {}\n" );
                 }
