@@ -302,6 +302,7 @@ sub run_one_po4aconf {
     $expected{'output'}      = 1;
     $expected{'diff_output'} = 1;
   FILE: foreach my $file ( glob("$tmppath/*") ) {
+        note("Seen file $file");
         $file =~ s|$tmppath/||;
         if ( not $expected{$file} ) {
             if ( ( $mode eq 'srcdir' || $mode eq 'dstdir' || $mode eq 'srcdstdir' ) ) {
@@ -406,7 +407,7 @@ sub run_one_format {
     # Normalize the document
     my $real_stderr = "$cwd/tmp/$path/$basename.norm.stderr";
     my $cmd =
-        "${execpath}/po4a-normalize -f $format --quiet "
+        "${execpath}/po4a-normalize --no-deprecation -f $format --quiet "
       . "--pot $cwd/${tmpbase}.pot --localized $cwd/${tmpbase}.norm $options $basename.$ext"
       . " > $real_stderr 2>&1";
 
@@ -442,7 +443,7 @@ sub run_one_format {
 
         # Translate the document
         $cmd =
-            "${execpath}/po4a-translate -f $format $options --master $basename.$ext"
+            "${execpath}/po4a-translate --no-deprecation -f $format $options --master $basename.$ext"
           . " --po $cwd/$pofile --localized $cwd/${tmpbase}.trans"
           . " > $cwd/$tmpbase.trans.stderr 2>&1";
 
@@ -460,7 +461,7 @@ sub run_one_format {
         # Update PO
         copy( "$cwd/$pofile", "$cwd/${tmpbase}.po_updated" ) || fail "Cannot copy $pofile before updating it";
         $cmd =
-            "${execpath}/po4a-updatepo -f $format $options "
+            "${execpath}/po4a-updatepo --no-deprecation -f $format $options "
           . "--master $basename.$ext --po $cwd/${tmpbase}.po_updated"
           . " > $cwd/tmp/$path/update.stderr 2>&1";
 
